<h2 align="center">A Palo Alto Panorama Sidekick</h2>

[![CI](https://github.com/johnjtorres/panorama-sidekick/actions/workflows/main.yml/badge.svg)](https://github.com/johnjtorres/panorama-sidekick/actions/workflows/main.yml)

## Features

- Print a list of managed device groups.

## TODO

- Print a list of managed firewalls.
- Print helpful information about firewalls (version, vsys, IP, uptime, etc.).
- Find security rules based on certain criteria and print in JSON.
- Run an operational command on Panorama or a firewall.
